@@ -1,7 +1,7 @@
 package Regexp::Stringify;
 
-our $DATE = '2016-03-15'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2016-10-29'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,7 +48,7 @@ still produce the former. It will also ignore regexp modifiers that are
 introduced in newer perls.
 
 Note that not all regexp objects are translatable to older perls, e.g. if they
-contain constructs not known to older perls like `(^...)` before perl 5.14.
+contain constructs not known to older perls like `(?^...)` before perl 5.14.
 
 _
         },
@@ -57,7 +57,7 @@ _
             description => <<'_',
 
 If you set this to 1, then `qr/a/i` will be stringified as `'qr/a/i'` instead as
-`'(^i:a)'`. The resulting string can then be eval-ed to recreate the Regexp
+`'(?^i:a)'`. The resulting string can then be eval-ed to recreate the Regexp
 object.
 
 _
@@ -108,7 +108,7 @@ Regexp::Stringify - Stringify a Regexp object
 
 =head1 VERSION
 
-This document describes version 0.05 of Regexp::Stringify (from Perl distribution Regexp-Stringify), released on 2016-03-15.
+This document describes version 0.06 of Regexp::Stringify (from Perl distribution Regexp-Stringify), released on 2016-10-29.
 
 =head1 SYNOPSIS
 
@@ -153,14 +153,14 @@ still produce the former. It will also ignore regexp modifiers that are
 introduced in newer perls.
 
 Note that not all regexp objects are translatable to older perls, e.g. if they
-contain constructs not known to older perls like C<(^...)> before perl 5.14.
+contain constructs not known to older perls like C<(?^...)> before perl 5.14.
 
 =item * B<regexp>* => I<re>
 
 =item * B<with_qr> => I<bool>
 
 If you set this to 1, then C<qr/a/i> will be stringified as C<'qr/a/i'> instead as
-C<'(^i:a)'>. The resulting string can then be eval-ed to recreate the Regexp
+C<'(?^i:a)'>. The resulting string can then be eval-ed to recreate the Regexp
 object.
 
 =back
